pub fn parse_with_untracked(raw_diff: &str) -> (DiffData, String)
Append synthetic diff for untracked files to a raw diff string, parse the combined result, and mark the untracked files in the returned DiffData.