pub fn remove_files_from_groups(
groups: &mut Vec<SemanticGroup>,
files_to_remove: &[String],
)Expand description
Remove all entries for the given file paths from existing groups. Groups that become empty after removal are dropped.
pub fn remove_files_from_groups(
groups: &mut Vec<SemanticGroup>,
files_to_remove: &[String],
)Remove all entries for the given file paths from existing groups. Groups that become empty after removal are dropped.