pub fn load_review_from_disk(
content_hash: u64,
current_source: &ReviewSource,
) -> Option<GroupReview>Expand description
Load a review from disk cache, validating against the current review source.
pub fn load_review_from_disk(
content_hash: u64,
current_source: &ReviewSource,
) -> Option<GroupReview>Load a review from disk cache, validating against the current review source.