Functions
- log_
file_ path - Return the path to the log file in the secure directory.
- pid_
file_ path - Return the path to the PID file in the secure directory.
- read_
pid - Read and parse the PID from the PID file. Returns None if the file is missing, contains invalid data, or the PID doesn’t belong to a semantic-diff process.
- remove_
pid_ file - Remove the PID file (best-effort, ignores errors).
- write_
pid_ file - Write the current process ID to the PID file atomically.