pub fn draw(app: &App, frame: &mut Frame<'_>) -> Vec<PendingImage>Expand description
Draw the entire UI. Returns pending images that must be flushed after terminal.draw() completes (image protocols bypass ratatui’s buffer).
pub fn draw(app: &App, frame: &mut Frame<'_>) -> Vec<PendingImage>Draw the entire UI. Returns pending images that must be flushed after terminal.draw() completes (image protocols bypass ratatui’s buffer).