pub struct PendingImage {
pub path: PathBuf,
pub x: u16,
pub y: u16,
pub width: u16,
pub height: u16,
}Expand description
Info about where an image should be rendered (collected during layout, written to stdout after ratatui flushes).
Fields
path: PathBufx: u16y: u16width: u16height: u16Auto Trait Implementations
impl Freeze for PendingImage
impl RefUnwindSafe for PendingImage
impl Send for PendingImage
impl Sync for PendingImage
impl Unpin for PendingImage
impl UnsafeUnpin for PendingImage
impl UnwindSafe for PendingImage