Module cache
semantic_
diff
0.6.0
Module cache
Module Items
Functions
In crate semantic_
diff
semantic_diff
Module
cache
Functions

diff_
hash
Compute a fast hash of the raw diff string.
get_
head_
commit
Return the current HEAD commit hash, or None if not in a git repo.
load
Try to load cached grouping for the given diff hash. Returns None if no cache, hash mismatch, parse error, or oversized file.
load_
incremental
Try to load cached grouping for the given HEAD commit (incremental mode). Returns the cached groups and file hashes so the caller can compute the delta. Returns None if no cache, HEAD mismatch, empty file hashes, parse error, or oversized file.
save_
with_
state
Save grouping result to the cache file with optional incremental state.