Module cache

Module cache 

Functions

diff_hash
Compute a fast hash of the raw diff string.
load
Try to load cached grouping for the given diff hash. Returns None if no cache, hash mismatch, parse error, or oversized file.
save
Save grouping result to the cache file.