pub fn load(hash: u64) -> Option<Vec<SemanticGroup>>Expand description
Try to load cached grouping for the given diff hash. Returns None if no cache, hash mismatch, parse error, or oversized file.
pub fn load(hash: u64) -> Option<Vec<SemanticGroup>>Try to load cached grouping for the given diff hash. Returns None if no cache, hash mismatch, parse error, or oversized file.