Module diff

Module diff 

Structs

DiffData
Top-level parsed diff result.
DiffFile
One changed file in the diff.
DiffLine
A single line within a hunk.
DiffSegment
A segment of a line for word-level inline diff highlighting.
Hunk
One @@ hunk section within a file.

Enums

LineType
Whether a diff line is added, removed, or context.
SegmentTag
Whether a segment is unchanged or changed in an inline diff.

Functions

parse
Parse raw git diff HEAD -M output into structured DiffData.