Markdown → ratatui Text rendering using pulldown-cmark.
Renders headings, tables, code blocks, lists, links, blockquotes, and inline formatting (bold, italic, code) as styled ratatui Lines.
Enums
- Preview
Block - Rendered markdown content: interleaved text blocks and mermaid placeholders.
Functions
- parse_
markdown - Parse markdown source and return a list of preview blocks.
widthis the available terminal columns for text wrapping (0 = no limit).