pub fn parse_markdown(
source: &str,
width: u16,
theme: &Theme,
) -> Vec<PreviewBlock>Expand description
Parse markdown source and return a list of preview blocks.
width is the available terminal columns for text wrapping (0 = no limit).