parse_markdown

Function parse_markdown 

pub fn parse_markdown(source: &str, width: u16) -> Vec<PreviewBlock>
Parse markdown source and return a list of preview blocks. width is the available terminal columns for text wrapping (0 = no limit).