pub fn parse_markdown(source: &str) -> Vec<PreviewBlock>Expand description
Parse markdown source and return a list of preview blocks.
pub fn parse_markdown(source: &str) -> Vec<PreviewBlock>Parse markdown source and return a list of preview blocks.