Module signal

Module signal 

Functions

log_file_path
Return the path to the log file in the secure directory.
pid_file_path
Return the path to the PID file in the secure directory.
read_pid
Read and parse the PID from the PID file. Returns None if the file is missing, contains invalid data, or the PID doesn’t belong to a semantic-diff process.
remove_pid_file
Remove the PID file (best-effort, ignores errors).
write_pid_file
Write the current process ID to the PID file atomically.